function csvexport(fname, data, doall_analyse, doquote, dotab)
% function csvexport(fname, data, doall_analyse, doquote, dotab)
% writes data in csv (comma separated)
% form into file fname.
% IN 
% fname:            string (file name)
% data:             matrix or mixed type cell array (double or strings)
%                   infromation to be written
% doall_analyse:    optional. if available and true 
%                   the type of every row is checked.
%                   This allows to write heterogeneous structures.
%                   It should do not be used if unnecesary since this
%                   generates considerable overhead. 
%  doquote:         optiuonal boolean, if 1 we quote strings.
%  dotab:           optional boolean, if 1 separators are tabs
%                   otherwise we use comma. 
% The usual functionality with cell arrays is that only the first and the
% second row of data are analysed and corresponding format strings
% generated. After the second the function assumes that all rows are
% identical. This allows to have a header line and data beneath.
%
% (C) P. Sykacek 2005

if nargin<4
    doquote=0;
end
if nargin<5
    dotab=0;
end

if isnumeric(data) % them matlab default works
    csvwrite(fname, data);
elseif iscell(data)
    if nargin < 3
        doall_analyse=0;
    end
    fid=fopen(fname, 'w');
    nrows=size(data, 1);
    formatstring=cellrow2form(data(1,:), 0, doquote, dotab);
    fprintf(fid, formatstring, data{1,:});
    formatstring=cellrow2form(data(2,:), 0, doquote, dotab);
    n=2;
    for n = 2:nrows
        if doall_analyse % geting it twice in one case shold outweigh the reduced efficiency of while loops?
            formatstring=cellrow2form(data(n,:), 0, doquote, dotab);
        end
        fprintf(fid, formatstring, data{n,:});
    end
    fclose(fid);
else
    warning('csvexport handles numerical matrices and cell arrays only');
end    
    