function [basedir]=getbasedir(varnam, default)
% function [basedir]=getbasedir(varnam, default)
% generate default package base directory.
% We first try to read the base dir name as
% contents of the environment varable provided as parameter.
% If that fails, we construct it using the
% default parameter, which allows a specification relative from the
% current directory. Tyically that will be
% none, one or more ../[../].
%
%  IN
%  varnam:    name of environment variable supposed to specify the
%             package base directory.
%  default:   relative path specification from current working \
%             directory that leads to the package base dir.
%  OUT
%  basedir:   package base directory.
%
%  (C) P. Sykacek 2006 <peter@sykacek.net>
  
  % construct a default relative path with dirs separated by
  % forward shalshes.
  if nargin < 2
    default='./';
  else
    idbslsh=find(default=='\\');
    if ~isempty(idbslsh)
      default(idbslsh)='/';
    end
  end
  % get basedir either from environment
  basedir=getenv(varnam);
  if isempty(basedir)  % or by construction from the currrent directory.
    basedir=pwd();
    % split basedir
    bslst={};
    while ~isempty(basedir)
      [tok, basedir]=strtok(basedir, '/');
      if ~isempty(tok)
	bslst=[bslst, {tok}];
      end
    end
    % split default
    dflst={};
    while ~isempty(default)	     
      [tok, default]=strtok(default, '/');
      if ~isempty(tok)
        dflst=[dflst, {tok}];
      end
    end
    %disp(bslst)
    %disp(dflst)
    % now construct basedir from bslst and default.
    ndef=length(dflst);
    nbd=length(bslst);
    n=1;
    % first we modify bslst
    while n <= ndef
      if strcmp(dflst{n}, '..')
	nbd=nbd-1;
      elseif strcmp(dflst{n}, '.')
      else
	nbd=nbd+1;
	bslst{nbd}=dflst{n};
      end
      n=n+1;
    end
    % and now we concatenate the new basedir
    n=1;
    basedir='/';
    while n <=nbd
      basedir=strcat(basedir,strcat(bslst{n},'/'));
      n=n+1;
    end
  else
    idbslsh=find(basedir==sprintf('\\'));
    if ~isempty(idbslsh)
      basedir(idbslsh)='/';
    end
  end
  