function [alltran, alltest]=msysnfldvdat(allsysdata, folds, fold, thissys)
% function [alltran, alltest]=msysnfldvdat(allsysdata, folds, fold, thissys)
% extracts current fold data from allsysdata.
% IN:
% allsysdata:   cell array of identically structured train arrays.
%               (same number of columns however different number of samples).
% folds:        overall number of folds.
% fold:         fold number
% thissys:      optional parameter that if presents selects the system index that
%               constitutes the current test case. (all other systems are training data only).
% OUT
% alltran,
% alltest:      cell arrays with a structure similar to allsysdata, however split up in
%               training and test data according to fold definitions.
%
% (C) P. Sykacek 2005

nsys=length(allsysdata);
if nargin<4
    thissys=0;
end
if thissys > 0
    for n=1:nsys
        if n==thissys
            [trandat, TrgTr, tstdat, TrgTs] = nfldvdat(allsysdata{n}, folds, fold, -1);
        else
            trandat=allsysdata{n};
            tstdat=[];
        end
        alltran{n}=trandat;
        alltest{n}=tstdat;
    end
else
    for n=1:nsys
        [trandat, TrgTr, tstdat, TrgTs] = nfldvdat(allsysdata{n}, folds, fold, -1);
        alltran{n}=trandat;
        alltest{n}=tstdat;
    end
end
